@@ -95,7 +95,10 @@ class ProblemParser:
         fluent_signature = {
             object_name: possible_objects[object_name].type for object_name in fluent_signature_items
         }
-        assert list(fluent_signature.values()) == list(lifted_function.signature.values())
+        for grounded_signature_type, lifted_signature_type in zip(fluent_signature.values(), lifted_function.signature.values()):
+            assert grounded_signature_type.is_sub_type(lifted_signature_type)
+
+        # assert list(fluent_signature.values()) == list(lifted_function.signature.values())
         return PDDLFunction(name=function_name, signature=fluent_signature)
 
     def parse_grounded_predicate(self, grounded_predicate_ast: List[str],
